pub struct decreaseAllowanceCall {
pub spender: Address,
pub subtractedValue: Uint<256, 4>,
}Available on crate feature
utils only.Expand description
Function with signature decreaseAllowance(address,uint256) and selector 0xa457c2d7.
solidity function decreaseAllowance(address spender, uint256 subtractedValue) external returns (bool);
Fields
spender: AddresssubtractedValue: Uint<256, 4>Trait Implementations
Sourceimpl Clone for decreaseAllowanceCall
impl Clone for decreaseAllowanceCall
Sourcefn clone(&self) -> decreaseAllowanceCall
fn clone(&self) -> decreaseAllowanceCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for decreaseAllowanceCall
impl Debug for decreaseAllowanceCall
Sourceimpl Default for decreaseAllowanceCall
impl Default for decreaseAllowanceCall
Sourcefn default() -> decreaseAllowanceCall
fn default() -> decreaseAllowanceCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for decreaseAllowanceCall
impl<'de> Deserialize<'de> for decreaseAllowanceCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<decreaseAllowanceCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<decreaseAllowanceCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for decreaseAllowanceCall
impl Hash for decreaseAllowanceCall
Sourceimpl PartialEq for decreaseAllowanceCall
impl PartialEq for decreaseAllowanceCall
Sourceimpl Serialize for decreaseAllowanceCall
impl Serialize for decreaseAllowanceCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for decreaseAllowanceCall
impl SolCall for decreaseAllowanceCall
Sourceconst SIGNATURE: &'static str = "decreaseAllowance(address,uint256)"
const SIGNATURE: &'static str = "decreaseAllowance(address,uint256)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address, Uint<256>)
type Parameters<'a> = (Address, Uint<256>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<decreaseAllowanceCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<decreaseAllowanceCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Bool,)
type ReturnTuple<'a> = (Bool,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<decreaseAllowanceCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<decreaseAllowanceCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<decreaseAllowanceCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> decreaseAllowanceCall
fn new<'a>( tuple: <<decreaseAllowanceCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> decreaseAllowanceCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <decreaseAllowanceCall as SolCall>::Token<'_>
fn tokenize(&self) -> <decreaseAllowanceCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<decreaseAllowanceCall as SolCall>::Return,
) -> <decreaseAllowanceCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<decreaseAllowanceCall as SolCall>::Return, ) -> <decreaseAllowanceCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<decreaseAllowanceCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<decreaseAllowanceCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<decreaseAllowanceCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<decreaseAllowanceCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for decreaseAllowanceCall
impl StructuralPartialEq for decreaseAllowanceCall