pub struct getAllocationCall {
pub operator: Address,
pub operatorSet: <OperatorSet as SolType>::RustType,
pub strategy: Address,
}Available on crate feature
utils only.Expand description
Function with signature getAllocation(address,(address,uint32),address) and selector 0x10e1b9b8.
solidity function getAllocation(address operator, OperatorSet memory operatorSet, address strategy) external view returns (IAllocationManagerTypes.Allocation memory);
Fields
operator: AddressoperatorSet: <OperatorSet as SolType>::RustTypestrategy: AddressTrait Implementations
Sourceimpl Clone for getAllocationCall
impl Clone for getAllocationCall
Sourcefn clone(&self) -> getAllocationCall
fn clone(&self) -> getAllocationCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getAllocationCall
impl Debug for getAllocationCall
Sourceimpl Default for getAllocationCall
impl Default for getAllocationCall
Sourcefn default() -> getAllocationCall
fn default() -> getAllocationCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getAllocationCall
impl<'de> Deserialize<'de> for getAllocationCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<getAllocationCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<getAllocationCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for getAllocationCall
impl Hash for getAllocationCall
Sourceimpl PartialEq for getAllocationCall
impl PartialEq for getAllocationCall
Sourceimpl Serialize for getAllocationCall
impl Serialize for getAllocationCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for getAllocationCall
impl SolCall for getAllocationCall
Sourceconst SIGNATURE: &'static str = "getAllocation(address,(address,uint32),address)"
const SIGNATURE: &'static str = "getAllocation(address,(address,uint32),address)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address, OperatorSet, Address)
type Parameters<'a> = (Address, OperatorSet, Address)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getAllocationCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getAllocationCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Allocation,)
type ReturnTuple<'a> = (Allocation,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getAllocationCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getAllocationCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<getAllocationCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> getAllocationCall
fn new<'a>( tuple: <<getAllocationCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> getAllocationCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <getAllocationCall as SolCall>::Token<'_>
fn tokenize(&self) -> <getAllocationCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<getAllocationCall as SolCall>::Return,
) -> <getAllocationCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<getAllocationCall as SolCall>::Return, ) -> <getAllocationCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<getAllocationCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<getAllocationCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<getAllocationCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<getAllocationCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for getAllocationCall
impl StructuralPartialEq for getAllocationCall