pub struct isMemberOfOperatorSetCall {
pub operator: Address,
pub operatorSet: <OperatorSet as SolType>::RustType,
}Available on crate feature
utils only.Expand description
Function with signature isMemberOfOperatorSet(address,(address,uint32)) and selector 0x670d3ba2.
solidity function isMemberOfOperatorSet(address operator, OperatorSet memory operatorSet) external view returns (bool);
Fields
operator: AddressoperatorSet: <OperatorSet as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for isMemberOfOperatorSetCall
impl Clone for isMemberOfOperatorSetCall
Sourcefn clone(&self) -> isMemberOfOperatorSetCall
fn clone(&self) -> isMemberOfOperatorSetCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for isMemberOfOperatorSetCall
impl Debug for isMemberOfOperatorSetCall
Sourceimpl Default for isMemberOfOperatorSetCall
impl Default for isMemberOfOperatorSetCall
Sourcefn default() -> isMemberOfOperatorSetCall
fn default() -> isMemberOfOperatorSetCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for isMemberOfOperatorSetCall
impl<'de> Deserialize<'de> for isMemberOfOperatorSetCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<isMemberOfOperatorSetCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<isMemberOfOperatorSetCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for isMemberOfOperatorSetCall
impl Hash for isMemberOfOperatorSetCall
Sourceimpl Serialize for isMemberOfOperatorSetCall
impl Serialize for isMemberOfOperatorSetCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for isMemberOfOperatorSetCall
impl SolCall for isMemberOfOperatorSetCall
Sourceconst SIGNATURE: &'static str = "isMemberOfOperatorSet(address,(address,uint32))"
const SIGNATURE: &'static str = "isMemberOfOperatorSet(address,(address,uint32))"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address, OperatorSet)
type Parameters<'a> = (Address, OperatorSet)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<isMemberOfOperatorSetCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<isMemberOfOperatorSetCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Bool,)
type ReturnTuple<'a> = (Bool,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<isMemberOfOperatorSetCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<isMemberOfOperatorSetCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<isMemberOfOperatorSetCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> isMemberOfOperatorSetCall
fn new<'a>( tuple: <<isMemberOfOperatorSetCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> isMemberOfOperatorSetCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <isMemberOfOperatorSetCall as SolCall>::Token<'_>
fn tokenize(&self) -> <isMemberOfOperatorSetCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<isMemberOfOperatorSetCall as SolCall>::Return,
) -> <isMemberOfOperatorSetCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<isMemberOfOperatorSetCall as SolCall>::Return, ) -> <isMemberOfOperatorSetCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<isMemberOfOperatorSetCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<isMemberOfOperatorSetCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<isMemberOfOperatorSetCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<isMemberOfOperatorSetCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for isMemberOfOperatorSetCall
impl StructuralPartialEq for isMemberOfOperatorSetCall