pub struct removeStrategiesFromOperatorSetCall {
pub avs: Address,
pub operatorSetId: u32,
pub strategies: Vec<Address>,
}Available on crate feature
utils only.Expand description
Function with signature removeStrategiesFromOperatorSet(address,uint32,address[]) and selector 0xb66bd989.
solidity function removeStrategiesFromOperatorSet(address avs, uint32 operatorSetId, address[] memory strategies) external;
Fields
avs: AddressoperatorSetId: u32strategies: Vec<Address>Trait Implementations
Sourceimpl Clone for removeStrategiesFromOperatorSetCall
impl Clone for removeStrategiesFromOperatorSetCall
Sourcefn clone(&self) -> removeStrategiesFromOperatorSetCall
fn clone(&self) -> removeStrategiesFromOperatorSetCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for removeStrategiesFromOperatorSetCall
impl Default for removeStrategiesFromOperatorSetCall
Sourcefn default() -> removeStrategiesFromOperatorSetCall
fn default() -> removeStrategiesFromOperatorSetCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for removeStrategiesFromOperatorSetCall
impl<'de> Deserialize<'de> for removeStrategiesFromOperatorSetCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<removeStrategiesFromOperatorSetCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<removeStrategiesFromOperatorSetCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for removeStrategiesFromOperatorSetCall
impl PartialEq for removeStrategiesFromOperatorSetCall
Sourcefn eq(&self, other: &removeStrategiesFromOperatorSetCall) -> bool
fn eq(&self, other: &removeStrategiesFromOperatorSetCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for removeStrategiesFromOperatorSetCall
impl Serialize for removeStrategiesFromOperatorSetCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for removeStrategiesFromOperatorSetCall
impl SolCall for removeStrategiesFromOperatorSetCall
Sourceconst SIGNATURE: &'static str = "removeStrategiesFromOperatorSet(address,uint32,address[])"
const SIGNATURE: &'static str = "removeStrategiesFromOperatorSet(address,uint32,address[])"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address, Uint<32>, Array<Address>)
type Parameters<'a> = (Address, Uint<32>, Array<Address>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<removeStrategiesFromOperatorSetCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<removeStrategiesFromOperatorSetCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = removeStrategiesFromOperatorSetReturn
type Return = removeStrategiesFromOperatorSetReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<removeStrategiesFromOperatorSetCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<removeStrategiesFromOperatorSetCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<removeStrategiesFromOperatorSetCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> removeStrategiesFromOperatorSetCall
fn new<'a>( tuple: <<removeStrategiesFromOperatorSetCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> removeStrategiesFromOperatorSetCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(
&self,
) -> <removeStrategiesFromOperatorSetCall as SolCall>::Token<'_>
fn tokenize( &self, ) -> <removeStrategiesFromOperatorSetCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<removeStrategiesFromOperatorSetCall as SolCall>::Return,
) -> <removeStrategiesFromOperatorSetCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<removeStrategiesFromOperatorSetCall as SolCall>::Return, ) -> <removeStrategiesFromOperatorSetCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<removeStrategiesFromOperatorSetCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<removeStrategiesFromOperatorSetCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<removeStrategiesFromOperatorSetCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<removeStrategiesFromOperatorSetCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for removeStrategiesFromOperatorSetCall
impl StructuralPartialEq for removeStrategiesFromOperatorSetCall