pub struct registerOperatorToAVSCall {
pub operator: Address,
pub operatorSignature: <SignatureWithSaltAndExpiry as SolType>::RustType,
}Available on crate feature
utils only.Expand description
Function with signature registerOperatorToAVS(address,(bytes,bytes32,uint256)) and selector 0x9926ee7d.
solidity function registerOperatorToAVS(address operator, ISignatureUtilsMixinTypes.SignatureWithSaltAndExpiry memory operatorSignature) external;
Fields
operator: AddressoperatorSignature: <SignatureWithSaltAndExpiry as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for registerOperatorToAVSCall
impl Clone for registerOperatorToAVSCall
Sourcefn clone(&self) -> registerOperatorToAVSCall
fn clone(&self) -> registerOperatorToAVSCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for registerOperatorToAVSCall
impl Debug for registerOperatorToAVSCall
Sourceimpl Default for registerOperatorToAVSCall
impl Default for registerOperatorToAVSCall
Sourcefn default() -> registerOperatorToAVSCall
fn default() -> registerOperatorToAVSCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for registerOperatorToAVSCall
impl<'de> Deserialize<'de> for registerOperatorToAVSCall
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<registerOperatorToAVSCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<registerOperatorToAVSCall, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for registerOperatorToAVSCall
impl Hash for registerOperatorToAVSCall
Sourceimpl Serialize for registerOperatorToAVSCall
impl Serialize for registerOperatorToAVSCall
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl SolCall for registerOperatorToAVSCall
impl SolCall for registerOperatorToAVSCall
Sourceconst SIGNATURE: &'static str = "registerOperatorToAVS(address,(bytes,bytes32,uint256))"
const SIGNATURE: &'static str = "registerOperatorToAVS(address,(bytes,bytes32,uint256))"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address, SignatureWithSaltAndExpiry)
type Parameters<'a> = (Address, SignatureWithSaltAndExpiry)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<registerOperatorToAVSCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<registerOperatorToAVSCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = registerOperatorToAVSReturn
type Return = registerOperatorToAVSReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<registerOperatorToAVSCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<registerOperatorToAVSCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(
tuple: <<registerOperatorToAVSCall as SolCall>::Parameters<'a> as SolType>::RustType,
) -> registerOperatorToAVSCall
fn new<'a>( tuple: <<registerOperatorToAVSCall as SolCall>::Parameters<'a> as SolType>::RustType, ) -> registerOperatorToAVSCall
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> <registerOperatorToAVSCall as SolCall>::Token<'_>
fn tokenize(&self) -> <registerOperatorToAVSCall as SolCall>::Token<'_>
Tokenize the call’s arguments.
Sourcefn tokenize_returns(
ret: &<registerOperatorToAVSCall as SolCall>::Return,
) -> <registerOperatorToAVSCall as SolCall>::ReturnToken<'_>
fn tokenize_returns( ret: &<registerOperatorToAVSCall as SolCall>::Return, ) -> <registerOperatorToAVSCall as SolCall>::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(
data: &[u8],
) -> Result<<registerOperatorToAVSCall as SolCall>::Return, Error>
fn abi_decode_returns( data: &[u8], ) -> Result<<registerOperatorToAVSCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(
data: &[u8],
) -> Result<<registerOperatorToAVSCall as SolCall>::Return, Error>
fn abi_decode_returns_validate( data: &[u8], ) -> Result<<registerOperatorToAVSCall as SolCall>::Return, Error>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for registerOperatorToAVSCall
impl StructuralPartialEq for registerOperatorToAVSCall